@@ -12,7 +12,6 @@ ExternalCallback = Callable[
     [AbstractDbModel | List[AbstractDbModel] | None], Coroutine[Any, Any, None]]
 
 
-
 async def exec_access(inc: InputContext,
                       model: Type[AbstractDbModel],
                       fetch_fields: List[str] = None,
@@ -74,3 +73,17 @@ async def exec_access(inc: InputContext,
     if isinstance(retrieved, list):
         return [await i.values_dict() for i in retrieved]
     return await retrieved.values_dict()
+
+
+async def exec_access_with_total(inc: InputContext,
+                      model: Type[AbstractDbModel],
+                      fetch_fields: List[str] = None,
+                      middleware: Type[ModelLoader] = ModelLoader,
+                      external_callback: ExternalCallback = None):
+    """Return from read_all dict with "items" and "total" """
+    result = await exec_access(inc=inc, model=model, fetch_fields=fetch_fields,
+                               middleware=middleware,
+                               external_callback=external_callback)
+    if inc.request.method == "GET" and isinstance(result, tuple):
+        return {"items": result[0], "total": result[1]}
+    return result
